@@ -166,8 +166,10 @@ js::JaegerSpew(js::JSpew_Insns, ISPFX "== add32(TrustedImm32 imm, RegisterID des
 js::JaegerSpew(js::JSpew_Insns, ISPFX "== add32(TrustedImm32 imm, RegisterID src, RegisterID dest) ==\n");
         if (PPC_IMM_OK_S(imm) && src != tempRegister) {
             m_assembler.addi(dest, src, int16_t(imm.m_value & 0xffff));
+        } else if (src == addressTempRegister) { // TenFourFox issue 211
+            move(imm, tempRegister);
+            m_assembler.add(dest, src, tempRegister);
         } else {
-            ASSERT(src != addressTempRegister);
             move(imm, addressTempRegister);
             m_assembler.add(dest, src, addressTempRegister);
         }
